@@ -1,6 +1,6 @@
-from wedeliver_core.wedeliver_core.helpers.amazon.get_file_url import get_file_url
+from wedeliver_core.helpers.amazon.get_file_url import get_file_url
 
-from wedeliver_core.wedeliver_core.helpers.amazon.get_s3_client import get_s3_client
+from wedeliver_core.helpers.amazon.get_s3_client import get_s3_client
 
 
 def append_plain_urls_to_list_dict(list_dict, key_name):
